<?php

spl_autoload_register(function ($class) {
    if (strpos($class, 'ZxcvbnPhp\\') !== false) {
        include(
            __DIR__ . DIRECTORY_SEPARATOR .
            str_replace(
                "\\",
                DIRECTORY_SEPARATOR,
                substr($class, 10)
            ) . ".php"
        );
    }
});
